@@ -3,7 +3,7 @@
 #include "radiostation.h"
 #include "texteditautoresizer.h"
 
-const QString appVersion = "1.0.4";
+const QString appVersion = "1.0.5";
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent), ui(new Ui::MainWindow), quitActionPressed(false), hideWhenClosing(false)
@@ -462,7 +462,7 @@ void MainWindow::on_stationsList_customContextMenuRequested(const QPoint &pos)
     menu.addMenu(&menuFavouritesManagement);
     menuFavouritesManagement.addAction(ui->actionAddToFavourites);
     menuFavouritesManagement.addAction(ui->actionDeleteFromFavourites);
-    menu.addAction(ui->actionRestoreDefaultList);
+    menu.addAction(ui->actionAddDefaultList);
     menu.addAction(ui->actionClearList);
     menu.exec(pos);
 }
@@ -483,25 +483,25 @@ void MainWindow::on_actionClearList_triggered()
     }
 }
 
-void MainWindow::on_actionRestoreDefaultList_triggered()
+void MainWindow::on_actionAddDefaultList_triggered()
 {
-    int ret = QMessageBox::warning(this, tr("Internet Radio Widget"),
+    /*int ret = QMessageBox::warning(this, tr("Internet Radio Widget"),
                                     tr("This will clear your stations list and restore default one."
                                        "<p>Do you really want to continue?"),
                                     QMessageBox::Yes | QMessageBox::Cancel);
 
-    if ( ret == QMessageBox::Yes)
-    {
-        stationsList.clear();
-        ui->stationsList->clear();
+    if ( ret == QMessageBox::Yes)*/
 
-        stationsDb.restoreDefaultDB();
+    stationsList.clear();
+    ui->stationsList->clear();
 
-        stationsList = stationsDb.getFullStationList(StationsDB::OrderByName);
+    stationsDb.addDefaultStations();
+
+    stationsList = stationsDb.getFullStationList(StationsDB::OrderByName);
+
+    saveStationsList();
+    populateList(stationsList);
 
-        saveStationsList();
-        populateList(stationsList);
-    }
 }
 
 QStringList MainWindow::getDefaultList()
@@ -758,3 +758,5 @@ void MainWindow::handleSwipe(MySwipeGesture::SwipeDirection direction)
 
 
 
+
+
