@@ -67,7 +67,6 @@ private slots:
     void on_actionAbout_Qt_triggered();
     void on_stationsList_customContextMenuRequested(const QPoint &pos);
     void on_actionClearList_triggered();
-    void on_actionRestoreDefaultList_triggered();
     void on_artistLineEdit_returnPressed();
     void on_titleLineEdit_returnPressed();
     void on_actionFilterListByCountry_triggered();
@@ -84,6 +83,8 @@ private slots:
     void on_actionAddToFavourites_triggered();
     void handleSwipe(MySwipeGesture::SwipeDirection);
 
+    void on_actionAddDefaultList_triggered();
+
 private:
     Ui::MainWindow *ui;
     QMediaPlayer* mediaPlayer;
